Function unicode::str::utf8_char_widthUnstable
[-] [+]
[src]
pub fn utf8_char_width(b: u8) -> usize
Given a first byte, determine how many bytes are in this UTF-8 character
pub fn utf8_char_width(b: u8) -> usize
Given a first byte, determine how many bytes are in this UTF-8 character
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).